@@ -6,6 +6,7 @@ A Python module containing common helper functions and variables for ReversingLa
 """
 
 import codecs
+import binascii
 from http import HTTPStatus
 
 
@@ -21,12 +22,14 @@ HASH_LENGTH_MAP = {
     128: SHA512
 }
 
+AVAILABLE_PLATFORMS = ("windows7", "windows10")
+
 DEFAULT_USER_AGENT = "ReversingLabs integrations default user agent"
 ADVANCED_SEARCH_SORTING_CRITERIA = ("sha1", "firstseen", "threatname", "sampletype", "filecount", "size")
 
 
 class NotFoundError(Exception):
-    def __init__(self, message="No reference was found for this input"):
+    def __init__(self, message="Not found. No reference was found for this input"):
         super(NotFoundError, self).__init__(message)
 
 
@@ -75,6 +78,11 @@ class InternalServerError(Exception):
         super(InternalServerError, self).__init__(message)
 
 
+class BadGatewayError(Exception):
+    def __init__(self, message="The server received an invalid response from another server"):
+        super(BadGatewayError, self).__init__(message)
+
+
 class ServiceUnavailableError(Exception):
     def __init__(self, message="Service unavailable"):
         super(ServiceUnavailableError, self).__init__(message)
@@ -86,7 +94,7 @@ class NotAllowedError(Exception):
 
 
 class TooManyRequestsError(Exception):
-    def __init__(self, message="Too many requests - limit reached"):
+    def __init__(self, message="Too many requests. Your quota limit might be reached"):
         super(TooManyRequestsError, self).__init__(message)
 
 
@@ -107,6 +115,7 @@ RESPONSE_CODE_ERROR_MAP = {
     HTTPStatus.CONFLICT: ConflictError,
     HTTPStatus.REQUEST_ENTITY_TOO_LARGE: RequestTooLargeError,
     HTTPStatus.INTERNAL_SERVER_ERROR: InternalServerError,
+    HTTPStatus.BAD_GATEWAY: BadGatewayError,
     HTTPStatus.SERVICE_UNAVAILABLE: ServiceUnavailableError
 }
 
@@ -118,10 +127,13 @@ def validate_hashes(hash_input, allowed_hash_types):
         :param allowed_hash_types: allowed hash types
         :type allowed_hash_types: tuple
     """
+    if not hash_input:
+        raise WrongInputError("At least one hash needs to be supplied as input.")
+
     for hash_string in hash_input:
         try:
             codecs.decode(hash_string, "hex")
-        except TypeError:
+        except (TypeError, binascii.Error):
             raise WrongInputError("The given hash input string is not a valid hexadecimal value.")
 
         hashing_algorithm = HASH_LENGTH_MAP.get(len(hash_string), None)
